@@ -241,8 +241,9 @@ class _SqliteAdvFuncHelper(db._GenericAdvFuncHelper):
     def restore_commands(self, backupfile, keepownership=True, drop=True,
                          dbname=None, dbhost=None, dbport=None, dbuser=None,
                          dbencoding=None):
-        gunziped, ext = os.splitext(backupfile)
-        assert ext.lower() in ('.gz', '.z') # else gunzip will fail anyway
+        gunziped, ext = os.path.splitext(backupfile)
+        msg = 'extension is %s but .gz or .z expected. Are you sure this is a sqlite dump?' % ext.lower()
+        assert ext.lower() in ('.gz', '.z'), msg # else gunzip will fail anyway
         return [['gunzip', backupfile], ['mv', gunziped, dbname or self.dbname]]
 
     def sql_create_index(self, table, column, unique=False):
