@@ -31,14 +31,14 @@ class PGHelperTC(TestCase):
         self.helper._cnx = self.cnx
 
     def test_type_map(self):
-        self.assertEquals(self.helper.TYPE_MAPPING['Datetime'], 'timestamp')
-        self.assertEquals(self.helper.TYPE_MAPPING['String'], 'text')
-        self.assertEquals(self.helper.TYPE_MAPPING['Password'], 'bytea')
-        self.assertEquals(self.helper.TYPE_MAPPING['Bytes'], 'bytea')
+        self.assertEqual(self.helper.TYPE_MAPPING['Datetime'], 'timestamp')
+        self.assertEqual(self.helper.TYPE_MAPPING['String'], 'text')
+        self.assertEqual(self.helper.TYPE_MAPPING['Password'], 'bytea')
+        self.assertEqual(self.helper.TYPE_MAPPING['Bytes'], 'bytea')
 
     def test_index_object(self):
         self.helper.index_object(1, IndexableObject())
-        self.assertEquals(self.cnx.received,
+        self.assertEqual(self.cnx.received,
                           [("INSERT INTO appears(uid, words, weight) "
                             "VALUES (%(uid)s, setweight(to_tsvector(%(config)s, %(wrds_A)s), 'A')||setweight(to_tsvector(%(config)s, %(wrds_B)s), 'B'), 1.0);",
                             {'wrds_B': 'cubic',
@@ -48,19 +48,19 @@ class PGHelperTC(TestCase):
 
     def test_fulltext_search_base(self):
         self.helper.fulltext_search(u'ginco-jpl')
-        self.assertEquals(self.cnx.received,
+        self.assertEqual(self.cnx.received,
                           [("SELECT 1, uid FROM appears WHERE words @@ to_tsquery(%(config)s, %(words)s)",
                             {'config': 'default', 'words': 'ginco&jpl'})])
 
     def test_fulltext_search_prefix_1(self):
         self.helper.fulltext_search(u'ginco*')
-        self.assertEquals(self.cnx.received,
+        self.assertEqual(self.cnx.received,
                           [("SELECT 1, uid FROM appears WHERE words @@ to_tsquery(%(config)s, %(words)s)",
                             {'config': 'default', 'words': 'ginco:*'})])
 
     def test_fulltext_search_prefix_2(self):
         self.helper.fulltext_search(u'ginc*o')
-        self.assertEquals(self.cnx.received,
+        self.assertEqual(self.cnx.received,
                           [("SELECT 1, uid FROM appears WHERE words @@ to_tsquery(%(config)s, %(words)s)",
                             {'config': 'default', 'words': 'ginc:*o'})])
 
